@@ -16,8 +16,8 @@ import matplotlib.pyplot as plt
 import matplotlib.patches as patches
 
 
-from eurocodes.en1993 import en1993_1_1, en1993_1_5, constants
-from sections.steel.steel_section import SteelSection
+from metku.eurocodes.en1993 import en1993_1_1, en1993_1_5, constants
+from metku.sections.steel.steel_section import SteelSection
 
 
 
